serialix
=======================================

.. contents:: Table of Contents
    :depth: 2
    :local:

About
--------------------------------------
``serialix`` is a powerful and easy-to-use tool that provides a unified interaction layer for various data interchange formats *(DIF)* like json, yaml, etc. Due to the how this tool designed, all the supported languages share the identical base between each other, meaning that process of working with those languages will be almost the same. Tool can also be extended for your purposes or even your own DIF language parser support.

Supported Languages
--------------------------------------
List of currently supported languages.

- Native Support
    - ``json``
- External Support
    - ``ujson`` *(replacement for python built-in json parser)*
    - ``yaml`` *(version <= 1.2)*
    - ``toml``

..

    Languages, listed in **Native Support** are supported by python without any external packages, while **External Support** requires external packages to be installed. For more detailed information go here: `Intallation Guide <https://maximilionus.github.io/serialix/guide_installation.html>`__

Documentation
--------------------------------------
All information about this module installation and usage is located in documentation `on this link <https://maximilionus.github.io/serialix/index.html>`__
